# xbutils

* cmd : Multi command argparse helper
* simple_config : simple configuration file
* template : text template
* textupdater : update text between special comments 
* htmlwriter  : write html